@@ -124,8 +124,8 @@ class ClientRAIDManagementTestCase(base.BaseTest):
             model='PERC H710 Mini',
             primary_status='ok',
             firmware_version='21.3.0-0009',
-            bus='1')
-
+            bus='1',
+            supports_realtime=True)
         mock_requests.post(
             'https://1.2.3.4:443/wsman',
             text=test_utils.RAIDEnumerations[uris.DCIM_ControllerView]['ok'])
@@ -283,8 +283,7 @@ class ClientRAIDManagementTestCase(base.BaseTest):
             physical_disks=[device_fqdd],
             raid_enable=True)
 
-        self.assertEqual({'commit_required': True,
-                          'is_commit_required': True,
+        self.assertEqual({'is_commit_required': True,
                           'is_reboot_required': constants.RebootRequired.true},
                          result)
         mock_invoke.assert_called_once_with(
@@ -315,8 +314,7 @@ class ClientRAIDManagementTestCase(base.BaseTest):
             physical_disks=device_list,
             raid_enable=True)
 
-        self.assertEqual({'commit_required': True,
-                          'is_commit_required': True,
+        self.assertEqual({'is_commit_required': True,
                           'is_reboot_required': constants.RebootRequired.true},
                          result)
         mock_invoke.assert_called_once_with(
@@ -345,8 +343,7 @@ class ClientRAIDManagementTestCase(base.BaseTest):
             physical_disks=[device_fqdd],
             raid_enable=False)
 
-        self.assertEqual({'commit_required': True,
-                          'is_commit_required': True,
+        self.assertEqual({'is_commit_required': True,
                           'is_reboot_required': constants.RebootRequired.true},
                          result)
         mock_invoke.assert_called_once_with(
@@ -378,8 +375,7 @@ class ClientRAIDManagementTestCase(base.BaseTest):
             physical_disks=device_list,
             raid_enable=False)
 
-        self.assertEqual({'commit_required': True,
-                          'is_commit_required': True,
+        self.assertEqual({'is_commit_required': True,
                           'is_reboot_required': constants.RebootRequired.true},
                          result)
         mock_invoke.assert_called_once_with(
@@ -424,8 +420,7 @@ class ClientRAIDManagementTestCase(base.BaseTest):
             raid_controller='controller', physical_disks=['disk1', 'disk2'],
             raid_level='1', size_mb=42)
 
-        self.assertEqual({'commit_required': True,
-                          'is_commit_required': True,
+        self.assertEqual({'is_commit_required': True,
                           'is_reboot_required': constants.RebootRequired.true},
                          result)
         mock_invoke.assert_called_once_with(
@@ -457,8 +452,7 @@ class ClientRAIDManagementTestCase(base.BaseTest):
             raid_level='1', size_mb=42, disk_name='name', span_length=2,
             span_depth=3)
 
-        self.assertEqual({'commit_required': True,
-                          'is_commit_required': True,
+        self.assertEqual({'is_commit_required': True,
                           'is_reboot_required': constants.RebootRequired.true},
                          result)
         mock_invoke.assert_called_once_with(
@@ -570,8 +564,7 @@ class ClientRAIDManagementTestCase(base.BaseTest):
 
         result = self.drac_client.delete_virtual_disk('disk1')
 
-        self.assertEqual({'commit_required': True,
-                          'is_commit_required': True,
+        self.assertEqual({'is_commit_required': True,
                           'is_reboot_required': constants.RebootRequired.true},
                          result)
         mock_invoke.assert_called_once_with(
@@ -597,25 +590,28 @@ class ClientRAIDManagementTestCase(base.BaseTest):
                        'create_config_job', spec_set=True, autospec=True)
     def test_commit_pending_raid_changes(self, mock_requests,
                                          mock_create_config_job):
-        self.drac_client.commit_pending_raid_changes('controller')
+        self.drac_client.commit_pending_raid_changes('controller',
+                                                     realtime=False)
 
         mock_create_config_job.assert_called_once_with(
             mock.ANY, resource_uri=uris.DCIM_RAIDService,
             cim_creation_class_name='DCIM_RAIDService',
             cim_name='DCIM:RAIDService', target='controller', reboot=False,
-            start_time='TIME_NOW')
+            start_time='TIME_NOW', realtime=False)
 
     @mock.patch.object(dracclient.resources.job.JobManagement,
                        'create_config_job', spec_set=True, autospec=True)
     def test_commit_pending_raid_changes_with_reboot(self, mock_requests,
                                                      mock_create_config_job):
-        self.drac_client.commit_pending_raid_changes('controller', reboot=True)
+        self.drac_client.commit_pending_raid_changes('controller',
+                                                     reboot=True,
+                                                     realtime=False)
 
         mock_create_config_job.assert_called_once_with(
             mock.ANY, resource_uri=uris.DCIM_RAIDService,
             cim_creation_class_name='DCIM_RAIDService',
             cim_name='DCIM:RAIDService', target='controller', reboot=True,
-            start_time='TIME_NOW')
+            start_time='TIME_NOW', realtime=False)
 
     @mock.patch.object(dracclient.resources.job.JobManagement,
                        'create_config_job', spec_set=True, autospec=True)
@@ -624,13 +620,14 @@ class ClientRAIDManagementTestCase(base.BaseTest):
             mock_create_config_job):
         timestamp = '20140924140201'
         self.drac_client.commit_pending_raid_changes('controller',
-                                                     start_time=timestamp)
+                                                     start_time=timestamp,
+                                                     realtime=False)
 
         mock_create_config_job.assert_called_once_with(
             mock.ANY, resource_uri=uris.DCIM_RAIDService,
             cim_creation_class_name='DCIM_RAIDService',
             cim_name='DCIM:RAIDService', target='controller', reboot=False,
-            start_time=timestamp)
+            start_time=timestamp, realtime=False)
 
     @mock.patch.object(dracclient.resources.job.JobManagement,
                        'create_config_job', spec_set=True, autospec=True)
@@ -640,13 +637,31 @@ class ClientRAIDManagementTestCase(base.BaseTest):
         timestamp = '20140924140201'
         self.drac_client.commit_pending_raid_changes('controller',
                                                      reboot=True,
-                                                     start_time=timestamp)
+                                                     start_time=timestamp,
+                                                     realtime=False)
 
         mock_create_config_job.assert_called_once_with(
             mock.ANY, resource_uri=uris.DCIM_RAIDService,
             cim_creation_class_name='DCIM_RAIDService',
             cim_name='DCIM:RAIDService', target='controller', reboot=True,
-            start_time=timestamp)
+            start_time=timestamp, realtime=False)
+
+    @mock.patch.object(dracclient.resources.job.JobManagement,
+                       'create_config_job', spec_set=True, autospec=True)
+    def test_commit_pending_raid_changes_with_realtime(
+            self, mock_requests,
+            mock_create_config_job):
+        timestamp = '20140924140201'
+        self.drac_client.commit_pending_raid_changes('controller',
+                                                     reboot=False,
+                                                     start_time=timestamp,
+                                                     realtime=True)
+
+        mock_create_config_job.assert_called_once_with(
+            mock.ANY, resource_uri=uris.DCIM_RAIDService,
+            cim_creation_class_name='DCIM_RAIDService',
+            cim_name='DCIM:RAIDService', target='controller', reboot=False,
+            start_time=timestamp, realtime=True)
 
     @mock.patch.object(dracclient.resources.job.JobManagement,
                        'delete_pending_config', spec_set=True, autospec=True)
@@ -659,6 +674,17 @@ class ClientRAIDManagementTestCase(base.BaseTest):
             cim_creation_class_name='DCIM_RAIDService',
             cim_name='DCIM:RAIDService', target='controller')
 
+    @mock.patch.object(dracclient.resources.job.JobManagement,
+                       'delete_pending_config', spec_set=True, autospec=True)
+    def test_abandon_pending_raid_changes_realtime(self, mock_requests,
+                                                   mock_delete_pending_config):
+        self.drac_client.abandon_pending_raid_changes('controller')
+
+        mock_delete_pending_config.assert_called_once_with(
+            mock.ANY, resource_uri=uris.DCIM_RAIDService,
+            cim_creation_class_name='DCIM_RAIDService',
+            cim_name='DCIM:RAIDService', target='controller')
+
     @mock.patch.object(dracclient.client.WSManClient,
                        'wait_until_idrac_is_ready', spec_set=True,
                        autospec=True)
@@ -779,11 +805,41 @@ class ClientRAIDManagementTestCase(base.BaseTest):
         self.assertFalse(self.drac_client
                          .is_raid_controller("notRAID.Integrated.1-1"))
 
-    def test_is_boss_controller(self, mock_requests):
+    @mock.patch.object(dracclient.client.WSManClient,
+                       'wait_until_idrac_is_ready', spec_set=True,
+                       autospec=True)
+    def test_is_boss_controller(self, mock_requests,
+                                mock_wait_until_idrac_is_ready):
+        mock_requests.post(
+            'https://1.2.3.4:443/wsman',
+            text=test_utils.RAIDEnumerations[uris.DCIM_ControllerView]['ok'])
         self.assertTrue(self.drac_client
                         .is_boss_controller("AHCI.Integrated.1-1"))
+
+    @mock.patch.object(dracclient.client.WSManClient,
+                       'wait_until_idrac_is_ready', spec_set=True,
+                       autospec=True)
+    def test_is_not_boss_controller(self, mock_requests,
+                                    mock_wait_until_idrac_is_ready):
+        mock_requests.post(
+            'https://1.2.3.4:443/wsman',
+            text=test_utils.RAIDEnumerations[uris.DCIM_ControllerView]['ok'])
         self.assertFalse(self.drac_client
-                         .is_boss_controller("notAHCI.Integrated.1-1"))
+                         .is_boss_controller("notAHCI.Integrated.1-1"),
+                         None)
+
+    @mock.patch.object(dracclient.client.WSManClient,
+                       'wait_until_idrac_is_ready', spec_set=True,
+                       autospec=True)
+    def test_is_boss_controller_with_cntl_list(self, mock_requests,
+                                               mock_wait_until_idrac_is_ready):
+        mock_requests.post(
+            'https://1.2.3.4:443/wsman',
+            text=test_utils.RAIDEnumerations[uris.DCIM_ControllerView]['ok'])
+        controllers = self.drac_client.list_raid_controllers()
+        self.assertTrue(self.drac_client
+                        .is_boss_controller("AHCI.Integrated.1-1",
+                                            controllers))
 
     def test_check_disks_status_no_controllers(self, mock_requests):
         physical_disks = [self.disk_1, self.disk_2, self.disk_3, self.disk_4]
@@ -926,8 +982,7 @@ class ClientRAIDManagementTestCase(base.BaseTest):
         mock_requests.post(
             'https://1.2.3.4:443/wsman',
             text=test_utils.RAIDEnumerations[uris.DCIM_PhysicalDiskView]['ok'])
-        mock_convert_physical_disks.return_value = {'commit_required': True,
-                                                    'is_commit_required': True,
+        mock_convert_physical_disks.return_value = {'is_commit_required': True,
                                                     'is_reboot_required':
                                                     constants.RebootRequired
                                                     .true}
@@ -953,8 +1008,7 @@ class ClientRAIDManagementTestCase(base.BaseTest):
         physical_disks = [disk_1_non_raid, disk_2_non_raid,
                           self.disk_3, self.disk_4]
         mock_list_physical_disks.return_value = physical_disks
-        mock_convert_physical_disks.return_value = {'commit_required': True,
-                                                    'is_commit_required': True,
+        mock_convert_physical_disks.return_value = {'is_commit_required': True,
                                                     'is_reboot_required':
                                                     constants.RebootRequired
                                                     .true}
@@ -976,8 +1030,7 @@ class ClientRAIDManagementTestCase(base.BaseTest):
             mock_list_physical_disks):
         mode = constants.RaidStatus.raid
         physical_disks = [self.disk_1, self.disk_2, self.disk_3, self.disk_4]
-        mock_convert_physical_disks.return_value = {'commit_required': True,
-                                                    'is_commit_required': True,
+        mock_convert_physical_disks.return_value = {'is_commit_required': True,
                                                     'is_reboot_required':
                                                     constants.RebootRequired
                                                     .true}
@@ -1079,8 +1132,7 @@ class ClientRAIDManagementTestCase(base.BaseTest):
             text=test_utils.RAIDEnumerations[uris.DCIM_ControllerView]['ok'])
         mode = constants.RaidStatus.jbod
         physical_disks = [self.disk_1, self.disk_2, self.disk_3, self.disk_4]
-        mock_convert_physical_disks.return_value = {'commit_required': True,
-                                                    'is_commit_required': True,
+        mock_convert_physical_disks.return_value = {'is_commit_required': True,
                                                     'is_reboot_required':
                                                     constants.RebootRequired
                                                     .true}
@@ -1143,9 +1195,7 @@ class ClientRAIDManagementTestCase(base.BaseTest):
         '''Where convert_physical_disks() does not require a commit after
         executing, unlikely case but provides 100% code coverage of all
         logic branches.'''
-        mock_convert_physical_disks.return_value = {'commit_required':
-                                                    True,
-                                                    'is_commit_required':
+        mock_convert_physical_disks.return_value = {'is_commit_required':
                                                     False,
                                                     'is_reboot_required':
                                                     constants.RebootRequired
@@ -1153,3 +1203,37 @@ class ClientRAIDManagementTestCase(base.BaseTest):
         results = self.drac_client.change_physical_disk_state(mode)
         self.assertFalse(results["is_reboot_required"])
         self.assertEqual(len(results["commit_required_ids"]), 0)
+
+    @mock.patch.object(dracclient.client.WSManClient,
+                       'wait_until_idrac_is_ready', spec_set=True,
+                       autospec=True)
+    def test_is_realtime_supported_with_realtime_controller(
+            self,
+            mock_requests,
+            mock_wait_until_idrac_is_ready):
+        expected_raid_controller = 'RAID.Integrated.1-1'
+
+        mock_requests.post(
+            'https://1.2.3.4:443/wsman',
+            text=test_utils.RAIDEnumerations[uris.DCIM_ControllerView]['ok'])
+
+        self.assertTrue(
+                self.drac_client.is_realtime_supported(
+                    expected_raid_controller))
+
+    @mock.patch.object(dracclient.client.WSManClient,
+                       'wait_until_idrac_is_ready', spec_set=True,
+                       autospec=True)
+    def test_is_realtime_supported_with_non_realtime_controller(
+            self,
+            mock_requests,
+            mock_wait_until_idrac_is_ready):
+        expected_raid_controller = 'AHCI.Integrated.1-1'
+
+        mock_requests.post(
+            'https://1.2.3.4:443/wsman',
+            text=test_utils.RAIDEnumerations[uris.DCIM_ControllerView]['ok'])
+
+        self.assertFalse(
+                self.drac_client.is_realtime_supported(
+                    expected_raid_controller))
